@@ -8,27 +8,38 @@ import numpy as np
 from collections import OrderedDict
 from warnings import warn
 
-qual_cmaps = ['Pastel1', 'Pastel2', 'Paired', 'Accent', 'Dark2', 'Set1', 'Set2', 'Set3', 'tab10', 'tab20', 'tab20b',
-              'tab20c']
+qual_cmaps = ['Pastel1', 'Pastel2', 'Paired', 'Accent', 'Dark2', 'Set1',
+              'Set2', 'Set3', 'tab10', 'tab20', 'tab20b', 'tab20c']
 
 
-def auto_colormap(n_colors: int, cmap: str = 'hsv', output: str = 'mpl', spacing: str = 'uniform', alpha: float = 1.0) -> List[Union[QtGui.QColor, np.ndarray]]:
+def auto_colormap(
+        n_colors: int,
+        cmap: str = 'hsv',
+        output: str = 'mpl',
+        spacing: str = 'uniform',
+        alpha: float = 1.0
+    ) \
+        -> List[Union[QtGui.QColor, np.ndarray, str]]:
     """
     If non-qualitative map: returns list of colors evenly spread through the chosen colormap.
     If qualitative map: returns subsequent colors from the chosen colormap
 
     :param n_colors: Numbers of colors to return
     :param cmap:     name of colormap
+
     :param output:   option: 'mpl' returns RGBA values between 0-1 which matplotlib likes,
                      option: 'pyqt' returns QtGui.QColor instances that correspond to the RGBA values
+                     option: 'bokeh' returns hex strings that correspond to the RGBA values which bokeh likes
+
     :param spacing:  option: 'uniform' returns evenly spaced colors across the entire cmap range
                      option: 'subsequent' returns subsequent colors from the cmap
+
     :param alpha:    alpha level, 0.0 - 1.0
 
-    :return:         List of colors as either QColor or numpy array with length n_colors
+    :return:         List of colors as either ``QColor``, ``numpy.ndarray``, or hex ``str`` with length ``n_colors``
     """
 
-    valid = ['mpl', 'pyqt']
+    valid = ['mpl', 'pyqt', 'bokeh']
     if output not in valid:
         raise ValueError(f'output must be one {valid}')
 
@@ -62,9 +73,16 @@ def auto_colormap(n_colors: int, cmap: str = 'hsv', output: str = 'mpl', spacing
     colors = []
     for ix in range(n_colors):
         c = lut[cm_ixs[ix]]
+
         if output == 'pyqt':
             colors.append(mkColor(c))
-        else:
+
+        elif output == 'bokeh':
+            c = tuple(c[:3] * 255)
+            hc = '#%02x%02x%02x' % tuple(map(int, c))
+            colors.append(hc)
+
+        else:  # mpl
             colors.append(c)
 
     return colors
