@@ -1,4 +1,4 @@
-from ...common.configuration import HAS_CAIMAN
+from ...common.configuration import HAS_CAIMAN, HAS_TENSORFLOW
 
 __all__ = [
     'mesfile_io',
@@ -6,7 +6,9 @@ __all__ = [
     'tiff_io',
     'stimulus_mapping',
     'script_editor',
-    'suite2p'
+    'suite2p',
+    'femtonics_mesc',
+    'exporter'
 ]
 
 if HAS_CAIMAN:
@@ -19,3 +21,9 @@ if HAS_CAIMAN:
         'caiman_importer',
         'caiman_dfof'
     ]
+
+if HAS_TENSORFLOW:
+    __all__ += \
+        [
+            'nuset_segment',
+        ]
